@@ -17,7 +17,6 @@ after 'BUILD' => sub {
             builder => 'create_reg_attr',
             lookup  => [
                 '.*_json$',  '.*_yaml$', '.*_yml$', '.*_jsn$',
-                '.*_config', '.*_conf$'
             ]
         }
     );
@@ -27,14 +26,12 @@ after 'BUILD' => sub {
         {
             builder => 'process_directive_config',
             lookup  => [
-                '.*_json$',  '.*_yaml$', '.*_yml$', '.*_jsn$',
-                '.*_config', '.*_conf$'
-            ]
+                '.*_json$', '.*_yaml$', '.*_yml$', '.*_jsn$',
+            ],
         }
     );
 };
 
-
 =head3 process_directive_config
 
 ##TODO Think about adding in multiple files  - supported by Config::Any
@@ -49,6 +46,8 @@ sub process_directive_config {
     my $k    = shift;
     my $v    = shift;
 
+    return unless ref($v);
+
     my $file = $self->check_file_exists( $k, $v );
     return unless $file;
 
